#[non_exhaustive]pub struct CompatibleImage {
pub ami_id: Option<String>,
pub name: Option<String>,
}Expand description
A JSON-formatted object that describes a compatible Amazon Machine Image (AMI), including the ID and name for a Snow device AMI. This AMI is compatible with the device's physical hardware requirements, and it should be able to be run in an SBE1 instance on the device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ami_id: Option<String>The unique identifier for an individual Snow device AMI.
name: Option<String>The optional name of a compatible image.
Implementations
Sourceimpl CompatibleImage
impl CompatibleImage
Sourcepub fn builder() -> CompatibleImageBuilder
pub fn builder() -> CompatibleImageBuilder
Creates a new builder-style object to manufacture CompatibleImage.