#[non_exhaustive]pub struct TargetOnDeviceService {
pub service_name: Option<DeviceServiceName>,
pub transfer_option: Option<TransferOption>,
}Expand description
An object that represents the service or services on the Snow Family device that your transferred data will be exported from or imported into. Amazon Web Services Snow Family supports Amazon S3 and NFS (Network File System).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_name: Option<DeviceServiceName>Specifies the name of the service on the Snow Family device that your transferred data will be exported from or imported into.
transfer_option: Option<TransferOption>Specifies whether the data is being imported or exported. You can import or export the data, or use it locally on the device.
Implementations
Sourceimpl TargetOnDeviceService
impl TargetOnDeviceService
Sourcepub fn service_name(&self) -> Option<&DeviceServiceName>
pub fn service_name(&self) -> Option<&DeviceServiceName>
Specifies the name of the service on the Snow Family device that your transferred data will be exported from or imported into.
Sourcepub fn transfer_option(&self) -> Option<&TransferOption>
pub fn transfer_option(&self) -> Option<&TransferOption>
Specifies whether the data is being imported or exported. You can import or export the data, or use it locally on the device.
Sourceimpl TargetOnDeviceService
impl TargetOnDeviceService
Sourcepub fn builder() -> TargetOnDeviceServiceBuilder
pub fn builder() -> TargetOnDeviceServiceBuilder
Creates a new builder-style object to manufacture TargetOnDeviceService.